import Foundation
import heresdk

class GPXRecorder {

    private var gpxOutput: String = initializeGPXString()
    private var formatter = initializeDateFormatter()
    private var counter = 0

    func addLocations(locations: [Location]) {
        for location in locations {
            gpxOutput.append(Self.makeGPXPoint(location: location, dateFormatter: formatter))
            //print("Adding location: \(String(describing: location))")
            counter += 1
        }
    }

    func saveRecording() {
        gpxOutput.append(Self.finalizeGPXString())

        let currentTime = Date()

        let path = FileManager.default.urls(for: .documentDirectory, in: .userDomainMask)[0]
        let fileName = path.appendingPathComponent("\(formatter.string(from: currentTime)).gpx")

        do {
            try gpxOutput.write(to: fileName, atomically: true, encoding: String.Encoding.utf8)
            print("GPX trace saved. Saved \(self.counter) locations to \(fileName)")
        } catch {
            print("Failed to create GPX file: \(error)")
        }

        reset() // after saving, start over
    }

    private func reset() {
        self.counter = 0
        gpxOutput = Self.initializeGPXString()
    }

    private static func initializeGPXString() -> String {
        """
        <?xml version="1.0" encoding="UTF-8" standalone="no" ?>
        <gpx xmlns="http://www.topografix.com/GPX/1/1"
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
        xsi:schemaLocation="http://www.topografix.com/GPX/1/1 http://www.topografix.com/GPX/1/1/gpx.xsd"
        version="1.1" creator="HERESDK iOS Navigate Demo">
        <trk><trkseg>
        """
    }

    private static func initializeDateFormatter() -> DateFormatter {
           let formatter = DateFormatter()
           formatter.dateFormat = "yyyy-MM-dd'T'HH:mm:ss.SSS"
           return formatter
       }

    private static func finalizeGPXString() -> String {
        "</trkseg></trk></gpx>"
    }

    private static func makeGPXPoint(location: Location, dateFormatter: DateFormatter) -> String {
           """
           <trkpt lon="\(location.coordinates.longitude)" lat="\(location.coordinates.latitude)">
               <ele>\(location.coordinates.altitude ?? 0)</ele>
               <time>\(dateFormatter.string(from: location.time ?? Date()))</time>
               <extensions>
                    <speed>\(location.speedInMetersPerSecond ?? 0)</speed>
                    <course>\(location.bearingInDegrees ?? 0)</course>
                    <horizontalAccuracy>\(location.horizontalAccuracyInMeters ?? 0)</horizontalAccuracy>
                    <verticalAccuracy>\(location.verticalAccuracyInMeters ?? 0)</verticalAccuracy>
               </extensions>
           </trkpt>
           """
       }

}
