//
//  InfoBubble.swift
//  iOS Navigate Reference App
//
//  Created by Jonda, Sachin on 10.05.23.
//  Copyright © 2023 HERE Technologies. All rights reserved.
//

import SwiftUI

struct InfoBubbleView: View {

    private var titleText = ""
    private var addressText = ""
    private var telText = ""

    init(titleText: String, addressText: String, telText: String) {
            self.titleText = titleText
            self.addressText = addressText
            self.telText = telText
       }

    var body: some View {

        VStack(spacing: 0.0){
            HStack(alignment: .top) {
                Image(systemName: "flag.circle.fill")
                    .resizable()
                    .frame(width: 40.0, height: 40.0)
                    .padding(.all, 5.0)

                VStack(alignment: .leading) {
                    Text(self.titleText)
                        .font(.headline)
                    Text(self.addressText)
                        .font(.caption)
                        .fontWeight(.thin)
                    Text(self.telText)
                        .font(.caption)
                        .foregroundColor(Color.red)
                }
                .frame(height: 50)

                Spacer()
            }
            .padding(.all, 5.0)
            .background(LinearGradient( gradient: Gradient(colors: [SwiftUI.Color(#colorLiteral(red: 0, green: 0.3, blue: 0, alpha: 1)), SwiftUI.Color(#colorLiteral(red: 0.1, green: 0.4, blue: 0.1, alpha: 1))]), startPoint: .bottom, endPoint: .top) )
            .foregroundColor(Color.white)

            Triangle()
                .frame(width: 50.0, height: 25)
                .foregroundColor(SwiftUI.Color(#colorLiteral(red: 0, green: 0.3, blue: 0, alpha: 1)))
        }
        .frame(width: 200.0)
        .background(Color.clear)

    }

}

struct Triangle: Shape {
    func path(in rect: CGRect) -> Path {
        var path = Path()

        path.move(to: CGPoint(x: rect.minX, y: rect.minY))
        path.addLine(to: CGPoint(x: rect.midX, y: rect.maxY))
        path.addLine(to: CGPoint(x: rect.maxX, y: rect.minY))
        path.addLine(to: CGPoint(x: rect.minX, y: rect.minY))

        return path
    }
}

struct InfoBubble_Previews: PreviewProvider {
    static var previews: some View {
        InfoBubbleView(titleText: "Title", addressText: "Address", telText: "Phone" )
    }
}
