//
//  MapSchemeSelectorView.swift
//  iOS Navigate Reference App
//
//  Created by Jonda, Sachin on 25.04.23.
//  Copyright © 2023 HERE Technologies. All rights reserved.
//

import SwiftUI
import heresdk

struct MapSchemeSelectorView: View {

    @ObservedObject var mapController: MapController
    @ObservedObject var mapSettings: MapSettings

    var body: some View {

        ZStack {
            Rectangle()
            .foregroundColor(Color(red: 0.3, green: 0.3, blue: 0.3, opacity: 0.8))
            .cornerRadius(5.0)

            VStack(alignment: .center){

                Text("Map Style")
                    .foregroundColor(Color.white)
                    .font(.title)

                // Basic mapschemes
                VStack(alignment: .trailing) {
                    HStack {

                        Button(action: {
                            print("Changing mapscheme to normal day")
                            self.mapSettings.mapScheme = MapScheme.normalDay
                            self.mapController.reloadMapStyleSettings()
                            self.mapSettings.showingSchemeSwitcher = false
                        } )
                        {
                            Image("day_normal")
                                .resizable()
                                .frame(width: 80.0, height: 80.0)
                                .clipShape(Circle())
                                .shadow(radius: 5)
                                .overlay(Circle().stroke(Color.white, lineWidth: 3))
                        }

                        Button(action: {
                            print("Changing mapscheme to hybrid day")
                            self.mapSettings.mapScheme = MapScheme.hybridDay
                            self.mapController.reloadMapStyleSettings()
                            self.mapSettings.showingSchemeSwitcher = false
                        } )
                        {
                            Image("day_hybrid")
                                .resizable()
                                .frame(width: 80.0, height: 80.0)
                                .clipShape(Circle())
                                .shadow(radius: 5)
                                .overlay(Circle().stroke(Color.white, lineWidth: 3))
                        }

                        Button(action: {
                            print("Changing mapscheme to normal night")
                            self.mapSettings.mapScheme = MapScheme.normalNight
                            self.mapController.reloadMapStyleSettings()
                            self.mapSettings.showingSchemeSwitcher = false
                        } )
                        {
                            Image("night_normal")
                                .resizable()
                                .frame(width: 80.0, height: 80.0)
                                .clipShape(Circle())
                                .shadow(radius: 5)
                                .overlay(Circle().stroke(Color.white, lineWidth: 3))
                        }
                    }
                    .padding(.vertical)
                }

                // Additional myp styles on top
                VStack(alignment: .trailing){
                    HStack {
                        // Traffic Mode picker
                        Text("Traffic flow:")
                            .foregroundColor(.white)
                            .lineLimit(1)
                            .font(.callout)

                        Picker(selection: self.$mapSettings.trafficFlowVisible.onChange({_ in
                            self.mapController.reloadMapStyleSettings()
                        }), label: EmptyView()) {
                            Image(systemName: "eye")
                                .imageScale(.medium)
                                .tag(true)

                            Image(systemName: "eye.slash")
                                .imageScale(.medium)
                                .tag(false)
                        }
                        .pickerStyle(SegmentedPickerStyle())
                        .frame(minWidth: 50, idealWidth: 100, maxWidth: 150, minHeight: 30, idealHeight: 30, maxHeight: 30, alignment: .center)

                    }

                    HStack {
                        // Traffic Mode picker
                        Text("Traffic incidents:")
                            .foregroundColor(.white)
                            .lineLimit(1)
                            .font(.callout)

                        Picker(selection: self.$mapSettings.trafficIncidentsVisible.onChange({_ in
                            self.mapController.reloadMapStyleSettings()
                        }), label: EmptyView()) {
                            Image(systemName: "eye")
                                .imageScale(.medium)
                                .tag(true)

                            Image(systemName: "eye.slash")
                                .imageScale(.medium)
                                .tag(false)
                        }
                        .pickerStyle(SegmentedPickerStyle())
                        .frame(minWidth: 50, idealWidth: 100, maxWidth: 150, minHeight: 30, idealHeight: 30, maxHeight: 30, alignment: .center)
                    }

                    HStack {
                        Text("Extr. buildings:")
                            .font(.callout)
                            .foregroundColor(.white)
                            .lineLimit(1)

                        Picker(selection: self.$mapSettings.extrudedBuildingsVisible.onChange({_ in
                            self.mapController.reloadMapStyleSettings()
                        }), label: EmptyView()) {
                            Image(systemName: "eye")
                                .imageScale(.medium)
                                .tag(true)

                            Image(systemName: "eye.slash")
                                .imageScale(.medium)
                                .tag(false)
                        }
                        .pickerStyle(SegmentedPickerStyle())
                        .frame(minWidth: 50, idealWidth: 100, maxWidth: 150, minHeight: 30, idealHeight: 30, maxHeight: 30, alignment: .center)
                    }

                    HStack {
                        Text("Building footprints:")
                            .foregroundColor(.white)
                            .lineLimit(1)
                            .font(.callout)

                        Picker(selection: self.$mapSettings.buildingFootprintsVisible.onChange({_ in
                            self.mapController.reloadMapStyleSettings()
                        }), label: EmptyView()) {
                            Image(systemName: "eye")
                                .imageScale(.medium)
                                .tag(true)

                            Image(systemName: "eye.slash")
                                .imageScale(.medium)
                                .tag(false)
                        }
                        .pickerStyle(SegmentedPickerStyle())
                        .frame(minWidth: 50, idealWidth: 100, maxWidth: 150, minHeight: 30, idealHeight: 30, maxHeight: 30, alignment: .center)
                    }

                    HStack {
                        Text("Vehicle restrict.:")
                            .foregroundColor(.white)
                            .lineLimit(1)
                            .font(.callout)

                        Picker(selection: self.$mapSettings.vehicleRestrictionsVisible.onChange({_ in
                            self.mapController.reloadMapStyleSettings()
                        }), label: EmptyView()) {
                            Image(systemName: "eye")
                                .imageScale(.medium)
                                .tag(true)

                            Image(systemName: "eye.slash")
                                .imageScale(.medium)
                                .tag(false)
                        }
                        .pickerStyle(SegmentedPickerStyle())
                        .frame(minWidth: 50, idealWidth: 100, maxWidth: 150, minHeight: 30, idealHeight: 30, maxHeight: 30, alignment: .center)
                    }
                    
                    HStack {
                        Text("Conge./Env. zones:")
                            .foregroundColor(.white)
                            .lineLimit(1)
                            .font(.callout)

                        Picker(selection: self.$mapSettings.congestionZonesVisible.onChange({_ in
                            self.mapController.reloadMapStyleSettings()
                        }), label: EmptyView()) {
                            Image(systemName: "eye")
                                .imageScale(.medium)
                                .tag(true)

                            Image(systemName: "eye.slash")
                                .imageScale(.medium)
                                .tag(false)
                        }
                        .pickerStyle(SegmentedPickerStyle())
                        .frame(minWidth: 50, idealWidth: 100, maxWidth: 150, minHeight: 30, idealHeight: 30, maxHeight: 30, alignment: .center)
                    }
                    
                    HStack {
                        Text("3D Landmarks:")
                            .foregroundColor(.white)
                            .lineLimit(1)
                            .font(.callout)

                        Picker(selection: self.$mapSettings.landmarksVisible.onChange({_ in
                            self.mapController.reloadMapStyleSettings()
                        }), label: EmptyView()) {
                            Image(systemName: "eye")
                                .imageScale(.medium)
                                .tag(true)

                            Image(systemName: "eye.slash")
                                .imageScale(.medium)
                                .tag(false)
                        }
                        .pickerStyle(SegmentedPickerStyle())
                        .frame(minWidth: 50, idealWidth: 100, maxWidth: 150, minHeight: 30, idealHeight: 30, maxHeight: 30, alignment: .center)
                    }

                    HStack {
                        Text("Hillshading/Terrain:")
                            .foregroundColor(.white)
                            .lineLimit(1)
                            .font(.callout)

                        Picker(selection: self.$mapSettings.hillshadingVisible.onChange({_ in
                            self.mapController.reloadMapStyleSettings()
                        }), label: EmptyView()) {
                            Image(systemName: "eye")
                                .imageScale(.medium)
                                .tag(true)

                            Image(systemName: "eye.slash")
                                .imageScale(.medium)
                                .tag(false)
                        }
                        .pickerStyle(SegmentedPickerStyle())
                        .frame(minWidth: 50, idealWidth: 100, maxWidth: 150, minHeight: 30, idealHeight: 30, maxHeight: 30, alignment: .center)
                    }
                    
                }

            }

            .padding(.all)
        }

    }
}

struct MapSchemeSelectorView_Previews: PreviewProvider {
    static var previews: some View {
        MapSchemeSelectorView(mapController: MapController(settings: MapSettings()), mapSettings: MapSettings())
    }
}

