//
//  MapUpdaterView.swift
//  iOS Navigate Reference App
//
//  Created by Jonda, Sachin on 24.01.23.
//  Copyright © 2023 HERE Technologies. All rights reserved.
//

import SwiftUI
import heresdk

struct MapUpdaterView: View {

    @EnvironmentObject var mapUpdaterController: MapUpdaterController
    @ObservedObject var mapUpdateStatus = MapUpdateStatus()

    var body: some View {
        GeometryReader { geometry in

            VStack(alignment: .leading, spacing: 0) {

                HStack {
                    Text("Update maps")
                        .font(.title)
                        .foregroundColor(.white)
                        .lineLimit(2)

                    Spacer()

                    Image(systemName: "xmark.circle")
                        .foregroundColor(Color(#colorLiteral(red: 1, green: 1, blue: 1, alpha: 1)))
                        .imageScale(.large)
                }
                .padding(.all)
                .onTapGesture {
                    print("Closing MapUpdater dialog")
                    self.mapUpdaterController.mapSettings?.showingMapUpdater = false
                }


                // show loading indicator
                if self.mapUpdaterController.isMapUpdateCheckRunning == true {
                    Spacer()
                    HStack {
                        Spacer()
                        WaitingDialog(titleText: "Checking...")
                            .frame(width: geometry.size.width/1.5, height: geometry.size.height/3)
                        Spacer()
                    }
                    Spacer()
                } else {

                    VStack(alignment: .leading) {
                        Text("Current installed map: \(self.mapUpdaterController.getInstalledMapVersion())")
                            .font(.body)
                            .foregroundColor(Color.white)
                            .padding(.top, 10)

                        if self.mapUpdaterController.updateAvailability == .available {

                            // status updates (progress, delete, download buttons)
                            switch mapUpdateStatus.status {

                            case .Done:
                                HStack{
                                        Image(systemName: "xmark.square.fill")
                                                .foregroundColor(Color(#colorLiteral(red: 0.4666666687, green: 0.7647058964, blue: 0.2666666806, alpha: 1)))
                                                .imageScale(.large)
                                }

                            case .Progress(let p):
                                HStack {
                                    Text("\(p) %")
                                        .font(.subheadline)
                                        .lineLimit(1)
                                        .foregroundColor(.white)

                                    Image(systemName: "pause.rectangle.fill")
                                        .foregroundColor(Color(#colorLiteral(red: 0.7450980544, green: 0.1568627506, blue: 0.07450980693, alpha: 1)))
                                        .imageScale(.large)
                                }
                                .onTapGesture {
                                    mapUpdateStatus.cancel()
                                }

                            case .Error:
                                HStack {
                                    Text("Error")
                                        .font(.subheadline)
                                        .lineLimit(1)
                                        .foregroundColor(Color(#colorLiteral(red: 0.7450980544, green: 0.1568627506, blue: 0.07450980693, alpha: 1)))

                                    Image(systemName: "repeat.circle.fill")
                                        .foregroundColor(Color(#colorLiteral(red: 0.9529411793, green: 0.6862745285, blue: 0.1333333403, alpha: 1)))
                                        .imageScale(.large)
                                }
                                .onTapGesture {
                                    print("Retry map updates...")
                                    self.mapUpdaterController.updateMap(mapUpdateStatus: self.mapUpdateStatus)
                                }

                            default:  // None, Cancelled
                                HStack {
                                    Text("Update installed maps:")
                                        .foregroundColor(Color.white)
                                        .font(.body)

                                    Spacer()

                                    Image(systemName: "goforward")
                                        .imageScale(.large)
                                        .foregroundColor(.white)
                                }
                                .onTapGesture {
                                    print("Updating maps requested...")
                                    self.mapUpdaterController.updateMap(mapUpdateStatus: self.mapUpdateStatus)

                                }
                                .padding(.top, 10)

                        }

                        } else {
                            Text("No update available.")
                                .font(.body)
                                .foregroundColor(Color.white)
                                .padding(.top, 10)
                        }

                    }
                    .padding([.leading, .trailing])

                    Spacer()

                }

            }
            .padding(.bottom, geometry.safeAreaInsets.bottom )
            .padding(.top, geometry.safeAreaInsets.top )
            .background(Color(#colorLiteral(red: 0.2549019754, green: 0.2745098174, blue: 0.3019607961, alpha: 1)))
            .edgesIgnoringSafeArea(.all)
            //.frame(width: UIScreen.main.bounds.width, height: UIScreen.main.bounds.height)  // full screen
            .frame(width: geometry.size.width, height: geometry.size.height)  // full screen
            .onAppear {
                self.mapUpdaterController.checkForMapUpdates()
            }
        }
    }
}


struct MapUpdaterView_Previews: PreviewProvider {
    static var previews: some View {
        MapUpdaterView()
        .environmentObject( MapUpdaterController( mapSettings: MapSettings() ) )
    }
}
