//
//  NavigationDashboard.swift
//  iOS Navigate Reference App
//
//  Created by Jonda, Sachin on 11.06.22.
//  Copyright © 2023 HERE Technologies. All rights reserved.
//

import SwiftUI

struct NavigationDashboard: View {

    @ObservedObject var mapController: MapController

    var body: some View {

        VStack (spacing: 0){
            HStack {
                // maneuver icons and distance
                VStack (alignment: .center) {
                    Image(self.mapController.nextManeuverIcon)
                        .resizable()
                        .frame(width: 35, height: 35)
                        .foregroundColor(Color.white)

                    Text(Utils.formatDistance(meter: self.mapController.distanceToManeuver))
                        .foregroundColor(Color.white)
                        .font(.callout)
                        .multilineTextAlignment(.leading)
                        .truncationMode(.tail)
                        .lineLimit(1)
                }
                .frame(width: 70)
                .padding(.vertical, 5)

                // next street name and exit
                VStack (alignment: .center) {
                    // show exit information if available
                    if self.mapController.nextExitNr != nil {
                        Text("Exit \(self.mapController.nextExitNr!)")
                            .foregroundColor(Color.white)
                            .font(.footnote)
                            .multilineTextAlignment(.leading)
                            .truncationMode(.tail)
                            .lineLimit(1)
                            .padding(.bottom, 5)
                    }

                    // next street after maneuver
                    Text("\(self.mapController.nextStreet)")
                        .foregroundColor(Color.white)
                        .font(.headline)
                        .multilineTextAlignment(.leading)
                        .truncationMode(.tail)
                        .lineLimit(2)
                }
                .frame(maxWidth: .infinity)

                // route distance and time
                VStack(alignment: .leading) {
                    // distance
                    HStack {
                        Image(systemName: "flag.circle")
                            .resizable()
                            .frame(width: 20.0, height: 20.0 )
                            .foregroundColor(.white)

                        Text(Utils.formatDistance(meter: self.mapController.distanceToDestination))
                            .foregroundColor(Color.white)
                            .font(.callout)
                            .truncationMode(.tail)
                            .lineLimit(1)
                    }

                    // time
                    HStack {
                        Image(systemName: "clock")
                            .resizable()
                            .frame(width: 20.0, height: 20.0 )
                            .foregroundColor(.white)

                        Text(Utils.formatTime(seconds: self.mapController.timeToDestinationInSeconds))
                            .foregroundColor(Color.white)
                            .font(.callout)
                            .truncationMode(.tail)
                            .lineLimit(1)
                    }
                }
                .frame(width: 95)
                .padding(.vertical, 5)
            }
            .frame(height: 80.0)
            .background(Color(#colorLiteral(red: 0, green: 0.3, blue: 0, alpha: 1)))

            Divider()
                .frame(height: 1)
                .foregroundColor(Color.white)

            if self.mapController.nextNextManeuverIcon != nil {
                HStack {
                    Image(self.mapController.nextNextManeuverIcon!)
                        .resizable()
                        .frame(width: 20.0, height: 20.0)
                        .foregroundColor(SwiftUI.Color(#colorLiteral(red: 0.6000000238, green: 0.6000000238, blue: 0.6000000238, alpha: 1)))
                        .padding(.vertical, 5)
                        .padding(.leading)

                    // next street after maneuver
                    Text("\(self.mapController.nextNextStreet)")
                        .foregroundColor(SwiftUI.Color(#colorLiteral(red: 0.6000000238, green: 0.6000000238, blue: 0.6000000238, alpha: 1)))
                        .font(.subheadline)
                        .multilineTextAlignment(.leading)
                        .truncationMode(.tail)
                        .lineLimit(1)

                    Spacer()
                }
                .frame(height: 30.0)
                .background(Color(#colorLiteral(red: 0.2, green: 0.4, blue: 0.2, alpha: 1)))
            }
        }
    }

}

struct NavigationDashboard_Previews: PreviewProvider {
    static var previews: some View {
        NavigationDashboard(mapController: MapController(settings: MapSettings()))
    }
}
