//
//  NavigationStatusBar.swift
//  iOS Navigate Reference App
//
//  Created by Jonda, Sachin on 13.08.22.
//  Copyright © 2023 HERE Technologies. All rights reserved.
//

import SwiftUI
import heresdk

struct NavigationStatusBar: View {

    @ObservedObject var mapController: MapController
    @ObservedObject var mapSettings: MapSettings

    var body: some View {

        HStack {
            // start navigation button
            Button(action: {
                print("Navigation start/stop clicked")

                if !self.mapController.isNavigationInProgress {
                    self.mapController.startNavigation( isSimulated: self.mapSettings.simulationMode )
                }else{
                    self.mapController.stopNavigation()
                }
            } )
            {
                if !self.mapController.isNavigationInProgress {
                    if self.mapSettings.simulationMode == true
                    {
                        Image(systemName:"play.circle.fill")
                            .resizable()
                            .foregroundColor(Color.black)
                            .background(Color.white)
                            .clipShape(Circle())
                            .shadow(color: .gray, radius: 2, x: 3, y: 3)
                            .overlay(Circle().stroke(Color.white, lineWidth: 3))
                    } else if self.mapSettings.transportMode == TransportMode.pedestrian {
                        Image(systemName:"person.circle.fill")
                            .resizable()
                            .foregroundColor(Color.black)
                            .background(Color.white)
                            .clipShape(Circle())
                            .shadow(color: .gray, radius: 2, x: 3, y: 3)
                            .overlay(Circle().stroke(Color.white, lineWidth: 3))
                    } else if self.mapSettings.transportMode == TransportMode.scooter {
                        Image(systemName:"bicycle.circle.fill")
                            .resizable()
                            .foregroundColor(Color.black)
                            .background(Color.white)
                            .clipShape(Circle())
                            .shadow(color: .gray, radius: 2, x: 3, y: 3)
                            .overlay(Circle().stroke(Color.white, lineWidth: 3))
                    } else {
                        Image(systemName:"car.circle.fill")
                            .resizable()
                            .foregroundColor(Color.black)
                            .background(Color.white)
                            .clipShape(Circle())
                            .shadow(color: .gray, radius: 2, x: 3, y: 3)
                            .overlay(Circle().stroke(Color.white, lineWidth: 3))
                    }
                } else {
                    Image(systemName:"stop.circle.fill")
                        .resizable()
                        .foregroundColor(Color.black)
                        .background(Color.white)
                        .clipShape(Circle())
                        .overlay(Circle().stroke(Color.white, lineWidth: 3))
                }
            }
            .frame(width: 50.0,height: 50.0)
            .padding([.vertical, .leading])
            .disabled(self.mapController.centerOnPositionUpdate)  // keep disabled as long as no position update came in

            Spacer()

            // show current street label if navigation is active..
            if self.mapController.isNavigationInProgress {

                Text("\(self.mapController.currentStreet)")
                    .foregroundColor(Color.white)
                    .font(.headline)
                    .multilineTextAlignment(.leading)
                    .truncationMode(.tail)
                    .lineLimit(2)

                Spacer()

                // show current speed in this tile if in navigation
                Text("\(String(format: "%.0f", self.mapController.currentSpeed.rounded())) km/h")
                    .foregroundColor(self.mapController.isSpeeding ? Color.red : Color.green)
                    .font(.headline)
                    .multilineTextAlignment(.leading)
                    .truncationMode(.tail)
                    .lineLimit(1)
                    .padding(.trailing)
            }

        }
    }
}

struct NavigationStatusBar_Previews: PreviewProvider {
    static var previews: some View {
        NavigationStatusBar(mapController: MapController(settings: MapSettings()), mapSettings: MapSettings() )
    }
}
