//
//  SceneDelegate.swift
//  iOS Navigate Reference App
//
//  Created by Jonda, Sachin on 04.12.22.
//  Copyright © 2023 HERE Technologies. All rights reserved.
//

import UIKit
import SwiftUI

// I only do this to change statusbar to light fonts programatically,
// since I want to have a black design for my topbar that ignores safe area intentionally
// See https://stackoverflow.com/questions/57063142/swiftui-status-bar-color
class HereHostingController<Content>: UIHostingController<Content> where Content : View {
    override var preferredStatusBarStyle: UIStatusBarStyle {
        return .lightContent
    }
}

class SceneDelegate: UIResponder, UIWindowSceneDelegate {

    var window: UIWindow?

    let mapSettings = MapSettings()

    func scene(_ scene: UIScene, willConnectTo session: UISceneSession, options connectionOptions: UIScene.ConnectionOptions) {
        // Create the SwiftUI view that provides the window contents.
        let contentView = ContentView(settings: mapSettings)

        // Use a UIHostingController as window root view controller.
        if let windowScene = scene as? UIWindowScene {
            let window = UIWindow(windowScene: windowScene)
            //window.rootViewController = HereHostingController(rootView: contentView)
            window.rootViewController = UIHostingController(rootView: contentView)
            self.window = window
            window.makeKeyAndVisible()
        }
    }

    func sceneDidDisconnect(_ scene: UIScene) {
        print("Scene did disconnect")
        // Called as the scene is being released by the system.
        // This occurs shortly after the scene enters the background, or when its session is discarded.
        // Release any resources associated with this scene that can be re-created the next time the scene connects.
        // The scene may re-connect later, as its session was not neccessarily discarded (see `application:didDiscardSceneSessions` instead).

    }

    // Called when the scene has moved from an inactive state to an active state.
    // Use this method to restart any tasks that were paused (or not yet started) when the scene was inactive.
    func sceneDidBecomeActive(_ scene: UIScene) {
        print("Scene became active")

        // prevent screen lock for this application. beside appdelegate it also seems to get configured per scene  now with ios13 and higher.
        // See also https://www.timekl.com/blog/2020/05/30/is-isidletimerdisabled-disabled/
        // and https://stackoverflow.com/questions/54002649/ios-swift-uiapplication-shared-isidletimerdisabled-true-not-working-after-revi
        UIApplication.shared.isIdleTimerDisabled = true
    }

    func sceneWillResignActive(_ scene: UIScene) {
        print("Scene will resign active")
        // Called when the scene will move from an active state to an inactive state.
        // This may occur due to temporary interruptions (ex. an incoming phone call).

        // always save all settings when going to background
        self.mapSettings.saveSetting()
    }

    func sceneWillEnterForeground(_ scene: UIScene) {
        print("Scene will enter foreground")
        // Called as the scene transitions from the background to the foreground.
        // Use this method to undo the changes made on entering the background.
    }

    func sceneDidEnterBackground(_ scene: UIScene) {
        print("Scene did enter background")
        // Called as the scene transitions from the foreground to the background.
        // Use this method to save data, release shared resources, and store enough scene-specific state information
        // to restore the scene back to its current state.
    }


}

