//
//  SpeedLimitSign.swift
//  iOS Navigate Reference App
//
//  Created by Jonda, Sachin on 10.05.23.
//  Copyright © 2023 HERE Technologies. All rights reserved.
//

import SwiftUI
import heresdk

struct SpeedLimitSign: View {

    //Attention:
    // In case of unbounded speed limit, the value is zero.
    // In case of unknow speed information, value is nil.
    var speedLimitInMetersPerSecond: Double?

    var body: some View {

        GeometryReader { geometry in

            VStack {

                ZStack {
                    Circle()
                        .foregroundColor(Color.white)
                        .overlay(
                            Circle()
                                .stroke(self.speedLimitInMetersPerSecond == 0 ? Color.gray : Color.red, lineWidth: geometry.size.width/6)
                         )

                    if let speedLimit = self.speedLimitInMetersPerSecond {
                        if speedLimit == 0 {
                            // 0 is unlimited speed
                            Path { path in
                                path.move(to: CGPoint(x: 0, y: geometry.size.height))
                                path.addLine(to: CGPoint(x: geometry.size.width, y: 0))

                                path.move(to: CGPoint(x: 0, y: geometry.size.height-geometry.size.height/6))
                                path.addLine(to: CGPoint(x: geometry.size.width-geometry.size.width/6, y: 0))

                                path.move(to: CGPoint(x: geometry.size.width/6, y: geometry.size.height))
                                path.addLine(to: CGPoint(x: geometry.size.width, y: geometry.size.height/6))
                            }
                            .stroke(lineWidth: geometry.size.width/10)
                            .foregroundColor(Color.gray)
                        } else {
                                // update speed sign with speed limit
                                Text(String(format: "%.0f", speedLimit*Utils.METER_PER_SECOND_TO_KMH))
                                    .font(.system(size: geometry.size.width/2.5))
                                    .fontWeight(.heavy)
                                    .foregroundColor(Color(#colorLiteral(red: 0, green: 0, blue: 0, alpha: 1)))
                        }

                    }
                    else {
                        // nil, so unknown data
                        Text("?")
                            .font(.system(size: geometry.size.width/2.5))
                            .fontWeight(.heavy)
                            .foregroundColor(Color.black)
                    }

                }
                .background(Color.clear)
                .clipShape(Circle())
                .shadow(color: .gray, radius: 2, x: 3, y: 3)

            }
        }
    }

    struct SpeedLimitSign_Previews: PreviewProvider {
        static var previews: some View {
            SpeedLimitSign(speedLimitInMetersPerSecond: 130/Utils.METER_PER_SECOND_TO_KMH)
        }
    }

}

