//
//  WaitingDialog.swift
//  iOS Navigate Reference App
//
//  Created by Jonda, Sachin on 10.05.23.
//  Copyright © 2023 HERE Technologies. All rights reserved.
//

import SwiftUI

struct WaitingDialog: View {

    @State var titleText: String

    @State private var isAnimating = false

    var body: some View {
        ZStack {
            Rectangle()
                .frame(maxWidth: .infinity, maxHeight: .infinity)
                .foregroundColor(Color(#colorLiteral(red: 0.2549019754, green: 0.2745098174, blue: 0.3019607961, alpha: 1)))
                .cornerRadius(5.0)

            VStack {
                ZStack{
                    Circle()
                        .trim(from: 0, to: 1)
                        .stroke(Color(#colorLiteral(red: 1, green: 1, blue: 1, alpha: 1)), lineWidth: 5)
                        .frame(width:80, height:80)
                        .foregroundColor(Color(#colorLiteral(red: 0.7450980544, green: 0.1568627506, blue: 0.07450980693, alpha: 1))) // TODO: check folor setting here; since it seems to have no effect

                    Circle()
                        .trim(from: 0.7, to: 1)
                        .stroke(Color(#colorLiteral(red: 1, green: 1, blue: 1, alpha: 1)), lineWidth: 10)
                        .frame(width:50, height: 50)
                        .rotationEffect(Angle(degrees: self.isAnimating ? 360.0 : 0.0))
                        .animation(Animation.linear(duration: 1).repeatForever(autoreverses: false))
                        .foregroundColor(Color(#colorLiteral(red: 0.501960814, green: 0.501960814, blue: 0.501960814, alpha: 1)))
                        .onAppear { self.isAnimating = true }
                        .onDisappear { self.isAnimating = false }
                }
                .padding(.bottom, 10)

                Text(self.titleText)
                    .font(.headline)
                    .foregroundColor(Color(#colorLiteral(red: 1, green: 1, blue: 1, alpha: 1)))
                    .lineLimit(2)
            }
        }
    }
}

struct WaitingDialog_Previews: PreviewProvider {
    static var previews: some View {
        WaitingDialog(titleText: "Waiting...")
    }
}
